summaryrefslogtreecommitdiffabout
path: root/kabc/plugins/qtopia
authorulf69 <ulf69>2004-07-14 18:42:43 (UTC)
committer ulf69 <ulf69>2004-07-14 18:42:43 (UTC)
commitb371433c634ad75d5a66cd876e062888f1b3c761 (patch) (side-by-side diff)
tree614c319c5e752a7884b8a761cdc80541809c7584 /kabc/plugins/qtopia
parent7868ec2225272318048026a602b842b38a05347f (diff)
downloadkdepimpi-b371433c634ad75d5a66cd876e062888f1b3c761.zip
kdepimpi-b371433c634ad75d5a66cd876e062888f1b3c761.tar.gz
kdepimpi-b371433c634ad75d5a66cd876e062888f1b3c761.tar.bz2
implemented qtopia support
Diffstat (limited to 'kabc/plugins/qtopia') (more/less context) (ignore whitespace changes)
-rw-r--r--kabc/plugins/qtopia/qtopiaE.pro18
-rw-r--r--kabc/plugins/qtopia/resourceqtopia.cpp179
-rw-r--r--kabc/plugins/qtopia/resourceqtopia.h20
-rw-r--r--kabc/plugins/qtopia/resourceqtopiaconfig.cpp27
-rw-r--r--kabc/plugins/qtopia/resourceqtopiaconfig.h4
5 files changed, 92 insertions, 156 deletions
diff --git a/kabc/plugins/qtopia/qtopiaE.pro b/kabc/plugins/qtopia/qtopiaE.pro
index d945c31..d9fa87f 100644
--- a/kabc/plugins/qtopia/qtopiaE.pro
+++ b/kabc/plugins/qtopia/qtopiaE.pro
@@ -2,7 +2,6 @@ TEMPLATE = lib
CONFIG += qt warn_on
-#release debug
-TARGET = microkabc_qtopia
-INCLUDEPATH += ../.. ../../converter/opie ../../../microkde ../../../microkde/kdecore ../../../microkde/kio/kfile ../../../qtcompat $(QPEDIR)/include $(OPIEDIR)/include
+TARGET = microkabc_qtopia
+INCLUDEPATH += ../.. ../../converter/qtopia ../../../microkde ../../../microkde/kdecore ../../../microkde/kio/kfile ../../../microkde/kio/kio ../../../qtcompat $(QPEDIR)/include
@@ -14,9 +13,5 @@ LIBS += -lmicrokabc
LIBS += -L$(QPEDIR)/lib
-LIBS += -L$(OPIEDIR)/lib
-LIBS += -lopie
+LIBS += -lqpepim
LIBS += -lqpe
-LIBS += -lqte
-LIBS += -lmicrokabc_opieconverter
-#LIBS += -L../../lib/$(PLATFORM)
-
+LIBS += -lmicrokabc_qtopiaconverter
@@ -26,3 +21,3 @@ HEADERS = \
resourceqtopia.h \
- resourceqtopiaconfig.h \
+ resourceqtopiaconfig.h
@@ -30,3 +25,2 @@ SOURCES = \
resourceqtopia.cpp \
- resourceqtopiaconfig.cpp \
-
+ resourceqtopiaconfig.cpp
diff --git a/kabc/plugins/qtopia/resourceqtopia.cpp b/kabc/plugins/qtopia/resourceqtopia.cpp
index 3d9d28b..4854197 100644
--- a/kabc/plugins/qtopia/resourceqtopia.cpp
+++ b/kabc/plugins/qtopia/resourceqtopia.cpp
@@ -26,3 +26,2 @@ $Id$
*/
-
#include <sys/types.h>
@@ -35,3 +34,3 @@ $Id$
#include <qregexp.h>
-#include <qtimer.h>
+//US #include <qtimer.h>
@@ -44,9 +43,5 @@ $Id$
-//US #include "formatfactory.h"
-//US #include <qpe/qpeapplication.h>
+#include <qpe/pim/addressbookaccess.h>
-#include <opie/ocontactaccess.h>
-#include <opie/ocontactaccessbackend_xml.h>
-#include "resource.h"
#include "resourceqtopiaconfig.h"
@@ -54,3 +49,3 @@ $Id$
-#include "opieconverter.h"
+#include "qtopiaconverter.h"
@@ -63,3 +58,3 @@ extern "C"
{
- return new KRES::PluginFactory<ResourceOpie,ResourceOpieConfig>();
+ return new KRES::PluginFactory<ResourceQtopia,ResourceQtopiaConfig>();
}
@@ -67,14 +62,7 @@ extern "C"
-ResourceOpie::ResourceOpie( const KConfig *config )
+ResourceQtopia::ResourceQtopia( const KConfig *config )
: Resource( config ), mConverter (0)
{
+ // we can not choose the filename. Therefore use the default to display
QString fileName = QDir::homeDirPath() + "/Applications/addressbook/addressbook.xml";
-
- KConfig *cfg = (KConfig *)config;
- if ( cfg ) {
- fileName = cfg->readEntry( "FileName", fileName );
-
- }
-
-// qDebug("ResourceOpie::ResourceOpie : %s", fileName.latin1() );
@@ -83,6 +71,6 @@ ResourceOpie::ResourceOpie( const KConfig *config )
-ResourceOpie::ResourceOpie( const QString &fileName )
+ResourceQtopia::ResourceQtopia( const QString &fileName )
: Resource( 0 )
{
-// qDebug("ResourceOpie::ResourceOpie : 3 %s", fileName.latin1());
+// qDebug("ResourceFile::ResourceFile : 3 %s, %s", fileName.latin1(), formatName.latin1());
init( fileName );
@@ -90,6 +78,5 @@ ResourceOpie::ResourceOpie( const QString &fileName )
-void ResourceOpie::init( const QString &fileName )
+void ResourceQtopia::init( const QString &fileName )
{
-/*US we have no KDirWatch. SO simulate the signals from inside the apropriate methods
connect( &mDirWatch, SIGNAL( dirty(const QString&) ), SLOT( fileChanged() ) );
@@ -97,11 +84,7 @@ void ResourceOpie::init( const QString &fileName )
connect( &mDirWatch, SIGNAL( deleted(const QString&) ), SLOT( fileChanged() ) );
-*/
- //US opie addressbook is always readonly
-//US setReadOnly( true );
setFileName( fileName );
-
}
-ResourceOpie::~ResourceOpie()
+ResourceQtopia::~ResourceQtopia()
{
@@ -109,20 +92,13 @@ ResourceOpie::~ResourceOpie()
delete mConverter;
+
}
-void ResourceOpie::writeConfig( KConfig *config )
+void ResourceQtopia::writeConfig( KConfig *config )
{
- //US opie addressbook is always readonly
-//US setReadOnly( true );
-
Resource::writeConfig( config );
-
- config->writeEntry( "FileName", mFileName );
-
-// qDebug("ResourceFile::writeConfig format %s, %s", mFileName.latin1(), mFormatName.latin1());
-
}
-Ticket *ResourceOpie::requestSaveTicket()
+Ticket *ResourceQtopia::requestSaveTicket()
{
- kdDebug(5700) << "ResourceOpie::requestSaveTicket()" << endl;
+ kdDebug(5700) << "ResourceQtopia::requestSaveTicket()" << endl;
@@ -131,3 +107,3 @@ Ticket *ResourceOpie::requestSaveTicket()
if ( !lock( mFileName ) ) {
- kdDebug(5700) << "ResourceOpie::requestSaveTicket(): Unable to lock file '"
+ kdDebug(5700) << "ResourceQtopia::requestSaveTicket(): Unable to lock file '"
<< mFileName << "'" << endl;
@@ -139,6 +115,5 @@ Ticket *ResourceOpie::requestSaveTicket()
-bool ResourceOpie::doOpen()
+bool ResourceQtopia::doOpen()
{
-// qDebug("ResourceOpie::doOpen() %s", mFileName.latin1());
-/*US
+/*US
QFile file( mFileName );
@@ -169,3 +144,2 @@ bool ResourceOpie::doOpen()
*/
- qDebug("ResourceOpie::doOpen() has to be fixed - %s", mFileName.latin1());
return true;
@@ -173,17 +147,14 @@ bool ResourceOpie::doOpen()
-void ResourceOpie::doClose()
+void ResourceQtopia::doClose()
{
-// qDebug("ResourceOpie::doClose() %s", mFileName.latin1());
}
-bool ResourceOpie::load()
+bool ResourceQtopia::load()
{
-// qDebug("ResourceOpie::load() %s", mFileName.latin1());
- kdDebug(5700) << "ResourceOpie::load(): '" << mFileName << "'" << endl;
+ kdDebug(5700) << "ResourceQtopia::load(): '" << mFileName << "'" << endl;
+
+// qDebug("ResourceQtopia::load: Try to load file() %s", mFileName.latin1());
+
+ AddressBookAccess* access = new AddressBookAccess();
- qDebug("ResourceOpie::load: Try to load file() %s", mFileName.latin1());
-
- OContactAccessBackend_XML* backend = new OContactAccessBackend_XML( "KDEPim/Pi", mFileName );
- OContactAccess* access = new OContactAccess("KDEPim/Pi", 0l, backend, false);
-
if ( !access ) {
@@ -194,4 +165,2 @@ bool ResourceOpie::load()
- access -> setReadAhead( 32 ); // Use ReadAhead-Cache if available
-
bool res = false;
@@ -199,3 +168,3 @@ bool ResourceOpie::load()
{
- mConverter = new OpieConverter();
+ mConverter = new QtopiaConverter();
res = mConverter->init();
@@ -203,4 +172,4 @@ bool ResourceOpie::load()
{
- qDebug("Unable to initialize opie converter. Most likely a problem with the category file");
- addressBook()->error( i18n( "Unable to initialize opie converter. Most likely a problem with the category file" ) );
+ qDebug("Unable to initialize qtopia converter. Most likely a problem with the category file");
+ addressBook()->error( i18n( "Unable to initialize qtopia converter. Most likely a problem with the category file" ) );
delete access;
@@ -209,27 +178,23 @@ bool ResourceOpie::load()
}
+
+ { //create a new scope
+ AddressBookIterator it(*access);
+ const PimContact* contact;
-
- OContactAccess::List::Iterator it;
- OContactAccess::List allList = access->allRecords();
- for ( it = allList.begin(); it != allList.end(); ++it )
- {
- OContact c = (*it);
+ for (contact=it.toFirst(); it.current(); ++it) {
+ contact = it.current();
- KABC::Addressee addressee;
+ KABC::Addressee addressee;
- res = mConverter->opieToAddressee( c, addressee );
+ res = mConverter->qtopiaToAddressee( (*contact), addressee );
- if ( !addressee.isEmpty() && res )
- {
- addressee.setResource( this );
- addressBook()->insertAddressee( addressee );
+ if ( !addressee.isEmpty() && res )
+ {
+ addressee.setResource( this );
+ addressBook()->insertAddressee( addressee );
+ }
}
-
-// qDebug("found %s", c.fullName().latin1());
}
-
+
delete access;
- // it seems so, that deletion of access deletes backend as well
- //delete backend;
-
return true;
@@ -237,9 +202,7 @@ bool ResourceOpie::load()
-bool ResourceOpie::save( Ticket *ticket )
+bool ResourceQtopia::save( Ticket *ticket )
{
- qDebug("ResourceOpie::save() has to be fixed - %s", mFileName.latin1());
-/*US
-
- qDebug("ResourceOpie::save %s", mFileName.latin1());
- kdDebug(5700) << "ResourceOpie::save()" << endl;
+/*US
+// qDebug("ResourceFile::save format %s, %s", mFileName.latin1(), mFormatName.latin1());
+ kdDebug(5700) << "ResourceQtopia::save()" << endl;
@@ -247,3 +210,3 @@ bool ResourceOpie::save( Ticket *ticket )
QString extension = "_" + QString::number( QDate::currentDate().dayOfWeek() );
-*/
+
/*US we use a simpler method to create a backupfile
@@ -261,2 +224,3 @@ bool ResourceOpie::save( Ticket *ticket )
*/
+
/*US
@@ -284,15 +248,10 @@ bool ResourceOpie::save( Ticket *ticket )
- qDebug("ResourceOpie::save has to be changed");
+ qDebug("ResourceQtopia::save has to be changed");
*/
return true;
-
}
-bool ResourceOpie::lock( const QString &fileName )
+bool ResourceQtopia::lock( const QString &fileName )
{
- qDebug("ResourceOpie::lock() has to be fixed - %s", mFileName.latin1());
-
-/*US
-// qDebug("ResourceOpie::lock() %s", fileName.latin1());
- kdDebug(5700) << "ResourceOpie::lock()" << endl;
+ kdDebug(5700) << "ResourceQtopia::lock()" << endl;
@@ -336,13 +295,6 @@ bool ResourceOpie::lock( const QString &fileName )
return false;
-*/
-
- return true;
}
-void ResourceOpie::unlock( const QString &fileName )
+void ResourceQtopia::unlock( const QString &fileName )
{
- qDebug("ResourceOpie::unlock() has to be fixed - %s", mFileName.latin1());
-/*US
-// qDebug("ResourceOpie::unlock() %s", fileName.latin1());
-
QString fn = fileName;
@@ -358,23 +310,19 @@ void ResourceOpie::unlock( const QString &fileName )
addressBook()->emitAddressBookUnlocked();
-*/
}
-void ResourceOpie::setFileName( const QString &fileName )
+void ResourceQtopia::setFileName( const QString &fileName )
{
-/*US ToDo: no synchronization so far. Has to be changed in the future
mDirWatch.stopScan();
mDirWatch.removeFile( mFileName );
-*/
+
mFileName = fileName;
-
-/*US ToDo: no synchronization so far. Has to be changed in the future
mDirWatch.addFile( mFileName );
mDirWatch.startScan();
-*/
+
//US simulate KDirWatch event
- fileChanged();
+//US fileChanged();
}
-QString ResourceOpie::fileName() const
+QString ResourceQtopia::fileName() const
{
@@ -383,3 +331,3 @@ QString ResourceOpie::fileName() const
-void ResourceOpie::fileChanged()
+void ResourceQtopia::fileChanged()
{
@@ -393,15 +341,8 @@ void ResourceOpie::fileChanged()
-void ResourceOpie::removeAddressee( const Addressee &addr )
+void ResourceQtopia::removeAddressee( const Addressee &addr )
{
-/*US
- QFile::remove( QFile::encodeName( locateLocal( "data", "kabc/photos/" ) + addr.uid() ) );
- QFile::remove( QFile::encodeName( locateLocal( "data", "kabc/logos/" ) + addr.uid() ) );
- QFile::remove( QFile::encodeName( locateLocal( "data", "kabc/sounds/" ) + addr.uid() ) );
-*/
}
-void ResourceOpie::cleanUp()
+void ResourceQtopia::cleanUp()
{
-// qDebug("ResourceOpie::cleanup() %s", mFileName.latin1());
-
unlock( mFileName );
@@ -409,2 +350,2 @@ void ResourceOpie::cleanUp()
-//US #include "resourceopie.moc"
+//US #include "resourceqtopia.moc"
diff --git a/kabc/plugins/qtopia/resourceqtopia.h b/kabc/plugins/qtopia/resourceqtopia.h
index ea0b5ee..bf9dd45 100644
--- a/kabc/plugins/qtopia/resourceqtopia.h
+++ b/kabc/plugins/qtopia/resourceqtopia.h
@@ -28,4 +28,4 @@ $Id$
-#ifndef KABC_RESOURCEQTOPIA_H
-#define KABC_RESOURCEQTOPIA_H
+#ifndef KABC_RESOURCEOPIE_H
+#define KABC_RESOURCEOPIE_H
@@ -39,5 +39,2 @@ $Id$
-//class QTimer;
-//class FormatPlugin;
-
namespace KABC {
@@ -46,3 +43,4 @@ namespace KABC {
class ResourceConfigWidget;
-class OpieConverter;
+class QtopiaConverter;
+
/**
@@ -50,3 +48,3 @@ class OpieConverter;
*/
-class ResourceOpie : public Resource
+class ResourceQtopia : public Resource
{
@@ -61,3 +59,3 @@ public:
*/
- ResourceOpie( const KConfig *cfg );
+ ResourceQtopia( const KConfig *cfg );
@@ -66,3 +64,3 @@ public:
*/
- ResourceOpie( const QString &fileName );
+ ResourceQtopia( const QString &fileName );
@@ -71,3 +69,3 @@ public:
*/
- ~ResourceOpie();
+ ~ResourceQtopia();
@@ -140,3 +138,3 @@ protected:
private:
- OpieConverter* mConverter;
+ QtopiaConverter* mConverter;
diff --git a/kabc/plugins/qtopia/resourceqtopiaconfig.h b/kabc/plugins/qtopia/resourceqtopiaconfig.h
index 0d80625..6b90b64 100644
--- a/kabc/plugins/qtopia/resourceqtopiaconfig.h
+++ b/kabc/plugins/qtopia/resourceqtopiaconfig.h
@@ -37,3 +37,3 @@ namespace KABC {
-class ResourceOpieConfig : public KRES::ConfigWidget
+class ResourceQtopiaConfig : public KRES::ConfigWidget
{
@@ -42,3 +42,3 @@ class ResourceOpieConfig : public KRES::ConfigWidget
public:
- ResourceOpieConfig( QWidget* parent = 0, const char* name = 0 );
+ ResourceQtopiaConfig( QWidget* parent = 0, const char* name = 0 );
diff --git a/kabc/plugins/qtopia/resourceqtopiaconfig.cpp b/kabc/plugins/qtopia/resourceqtopiaconfig.cpp
index 8cb8505..b2310c4 100644
--- a/kabc/plugins/qtopia/resourceqtopiaconfig.cpp
+++ b/kabc/plugins/qtopia/resourceqtopiaconfig.cpp
@@ -48,7 +48,5 @@ using namespace KABC;
-ResourceOpieConfig::ResourceOpieConfig( QWidget* parent, const char* name )
+ResourceQtopiaConfig::ResourceQtopiaConfig( QWidget* parent, const char* name )
: ConfigWidget( parent, name )
{
-//qDebug("ResourceFileConfig::ResourceFileConfig");
-
QGridLayout *mainLayout = new QGridLayout( this, 1, 2, 0,
@@ -64,11 +62,12 @@ ResourceOpieConfig::ResourceOpieConfig( QWidget* parent, const char* name )
mainLayout->addWidget( mFileNameEdit, 0, 1 );
+
}
-void ResourceOpieConfig::loadSettings( KRES::Resource *res )
+void ResourceQtopiaConfig::loadSettings( KRES::Resource *res )
{
//US ResourceFile *resource = dynamic_cast<ResourceFile*>( res );
- ResourceOpie *resource = (ResourceOpie*)( res );
+ ResourceQtopia *resource = (ResourceQtopia*)( res );
if ( !resource ) {
- kdDebug(5700) << "ResourceOpieConfig::loadSettings(): cast failed" << endl;
+ kdDebug(5700) << "ResourceQtopiaConfig::loadSettings(): cast failed" << endl;
return;
@@ -79,14 +78,18 @@ void ResourceOpieConfig::loadSettings( KRES::Resource *res )
mFileNameEdit->setURL( QDir::homeDirPath() + "/Applications/addressbook/addressbook.xml" );
-
- //US Opie resources are ReadOnly by definition
+
+ //US Qtopia resources are ReadOnly by definition
emit setPersistentReadOnly( true );
+
+ //US we can not choose the filename for the qtopia backend => make it readonly.
+ mFileNameEdit->setEnabled( false );
+
}
-void ResourceOpieConfig::saveSettings( KRES::Resource *res )
+void ResourceQtopiaConfig::saveSettings( KRES::Resource *res )
{
//US ResourceFile *resource = dynamic_cast<ResourceFile*>( res );
- ResourceOpie *resource = (ResourceOpie*)( res );
+ ResourceQtopia *resource = (ResourceQtopia*)( res );
if ( !resource ) {
- kdDebug(5700) << "ResourceOpieConfig::saveSettings(): cast failed" << endl;
+ kdDebug(5700) << "ResourceQtopiaConfig::saveSettings(): cast failed" << endl;
return;
@@ -97,3 +100,3 @@ void ResourceOpieConfig::saveSettings( KRES::Resource *res )
-void ResourceOpieConfig::checkFilePermissions( const QString& fileName )
+void ResourceQtopiaConfig::checkFilePermissions( const QString& fileName )
{